"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
exports.hex2rgb = hex2rgb;
exports.hsb2rgb = hsb2rgb;
exports.hue2rgb = hue2rgb;
exports.rgb2hex = rgb2hex;
exports.rgb2hsb = rgb2hsb;
var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _Valid = _interopRequireDefault(require("./Valid"));
/**
 * @file Color vendor
 */

/**
 * Convert Hue percent value to RGB value
 * @param percent percent value {number}
 * @returns RGB {number[R, G, B]}
 * @private
 */
function _getHueRGB(percent) {
  var data = [[255, 0, 0], [255, 255, 0], [0, 255, 0], [0, 255, 255], [0, 0, 255], [255, 0, 255], [255, 0, 0]];
  if (_Valid["default"].isPerCent(percent)) {
    return data[Math.floor(percent * 6)];
  }
  return data[0];
}

/**
 * Convert Hue degree value to RGB value
 * @param hue degree value {number}
 * @returns RGB {number[R, G, B]}
 */
function hue2rgb(hue) {
  if (!_Valid["default"].isDeg(hue)) {
    return;
  }
  var percent = hue / 360,
    _int = Math.floor(percent * 6),
    offset = Math.round((percent * 6 - _int) * 255),
    rgb = _getHueRGB(percent);
  rgb[(_int * 2 + 1) % 3] += offset * (_Valid["default"].isOdd(_int) ? -1 : 1);
  return rgb;
}

/**
 * Convert RGB value to HSB value
 * @param rgb value {number[R, G, B]}
 * @returns HSB value {number[H, S, B]}
 */
function rgb2hsb(rgb) {
  if (!_Valid["default"].isRGB(rgb)) {
    return null;
  }
  var _rgb = (0, _slicedToArray2["default"])(rgb, 3),
    r = _rgb[0],
    g = _rgb[1],
    b = _rgb[2],
    max = Math.max.apply(Math, (0, _toConsumableArray2["default"])(rgb)),
    min = Math.min.apply(Math, (0, _toConsumableArray2["default"])(rgb));
  var h = 0;
  if (max === r && g >= b) {
    h = (g - b) * 60 / (max - min);
  } else if (max === r && g < b) {
    h = (g - b) * 60 / (max - min) + 360;
  } else if (max === g) {
    h = (b - r) * 60 / (max - min) + 120;
  } else if (max === b) {
    h = (r - g) * 60 / (max - min) + 240;
  }
  return [h ? Math.round(h) : h, max === 0 ? 0 : (max - min) / max, max / 255];
}

/**
 * Convert HSB value to RGB value
 * @param hsb value {number[H, S, B]}
 * @returns RGB value {number[R, G, B]}
 */
function hsb2rgb(hsb) {
  if (!_Valid["default"].isHSB(hsb)) {
    return null;
  }
  var _hsb = (0, _slicedToArray2["default"])(hsb, 3),
    h = _hsb[0],
    s = _hsb[1],
    v = _hsb[2];
  h = h === 360 ? 0 : h;
  var i = Math.floor(h / 60) % 6,
    f = h / 60 - i,
    p = v * (1 - s),
    q = v * (1 - f * s),
    t = v * (1 - (1 - f) * s);
  var r = 0,
    g = 0,
    b = 0;
  switch (i) {
    case 0:
      r = v;
      g = t;
      b = p;
      break;
    case 1:
      r = q;
      g = v;
      b = p;
      break;
    case 2:
      r = p;
      g = v;
      b = t;
      break;
    case 3:
      r = p;
      g = q;
      b = v;
      break;
    case 4:
      r = t;
      g = p;
      b = v;
      break;
    case 5:
      r = v;
      g = p;
      b = q;
      break;
  }
  return [Math.round(r * 255), Math.round(g * 255), Math.round(b * 255)];
}

/**
 * Convert RGB value to hex format
 * @param rgb value {number[R, G, B]}
 * @returns RGB hex value {string}
 */
function rgb2hex(rgb) {
  if (!rgb || !_Valid["default"].isRGB(rgb)) {
    return;
  }
  return rgb.map(function (item) {
    var result = item.toString(16);
    return result.length < 2 ? "0".concat(result) : result;
  }).join('');
}

/**
 * Convert RGB hex value to RGB format
 * @param hex hex value {string}
 * @returns RGB value {number[R, G, B]}
 */
function hex2rgb(hex) {
  if (!_Valid["default"].isHex(hex)) {
    return;
  }
  var hasHash = hex[0] === '#';
  var hexValue = hasHash ? hex.slice(1) : hex;
  var isAbbr = hexValue.length === 3;
  if (isAbbr) {
    return hexValue.split('').map(function (item) {
      return parseInt("".concat(item).concat(item), 16);
    });
  }
  return [hexValue.slice(0, 2), hexValue.slice(2, 4), hexValue.slice(4, 6)].map(function (item) {
    return parseInt(item, 16);
  });
}
var _default = {
  hue2rgb: hue2rgb,
  rgb2hsb: rgb2hsb,
  hsb2rgb: hsb2rgb,
  rgb2hex: rgb2hex,
  hex2rgb: hex2rgb
};
exports["default"] = _default;